what.models.detection.ssd.ssd.squeezenet_ssd_config API documentation

# what.models.detection.ssd.ssd.squeezenet_ssd_config

View Source

     1import numpy as np
     2
     3from ..utils.box_utils import SSDSpec, SSDBoxSizes, generate_ssd_priors
     4
     5
     6image_size = 300
     7image_mean = np.array([127, 127, 127])  # RGB layout
     8image_std = 128.0
     9iou_threshold = 0.45
    10center_variance = 0.1
    11size_variance = 0.2
    12
    13specs = [
    14    SSDSpec(17, 16, SSDBoxSizes(60, 105), [2, 3]),
    15    SSDSpec(10, 32, SSDBoxSizes(105, 150), [2, 3]),
    16    SSDSpec(5, 64, SSDBoxSizes(150, 195), [2, 3]),
    17    SSDSpec(3, 100, SSDBoxSizes(195, 240), [2, 3]),
    18    SSDSpec(2, 150, SSDBoxSizes(240, 285), [2, 3]),
    19    SSDSpec(1, 300, SSDBoxSizes(285, 330), [2, 3])
    20]
    21
    22
    23priors = generate_ssd_priors(specs, image_size)